| CTS_append_report | R Documentation |
Appends report elements to a formods report.
CTS_append_report(state, rpt, rpttype, gen_code_only = FALSE)
state |
CTS state from |
rpt |
Report with the current content of the report which will be appended to in
this function. For details on the structure see the documentation for
|
rpttype |
Type of report to generate (supported "xlsx", "pptx", "docx"). |
gen_code_only |
Boolean value indicating that only code should be
generated ( |
list containing the following elements
isgood: Return status of the function.
hasrptele: Boolean indicator if the module has any reportable elements.
code: Code to generate reporting elements.
msgs: Messages to be passed back to the user.
rpt: Report with any additions passed back to the user.
formods::FM_generate_report() and
onbrand::template_details()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.