| CTS_init_element_model | R Documentation |
When a source model changes this will update information about that model like the default dvcols and selection information about the dvcols
CTS_init_element_model(state, element)
state |
CTS state from |
element |
Element list from |
CTS state object with the current cohort ui elements initialized based on the current model selected
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.