CTS_sim_isgood: Checks Simulation in Element for Goodness

View source: R/CTS_Server.R

CTS_sim_isgoodR Documentation

Checks Simulation in Element for Goodness

Description

Takes the supplied element and determines if the underlying simulation is in a good state or not.

Usage

CTS_sim_isgood(state, element)

Arguments

state

CTS state from CTS_fetch_state()

element

Element list from CTS_fetch_current_element()

Value

List with the following elements:

  • isgood: Boolean object indicating if the file was successfully loaded.

  • msgs: Text description of failure.


ruminate documentation built on Nov. 5, 2025, 5:34 p.m.