CTS_test_mksession: Populate Session Data for Module Testing

View source: R/CTS_Server.R

CTS_test_mksessionR Documentation

Populate Session Data for Module Testing

Description

Populates the supplied session variable for testing.

Usage

CTS_test_mksession(session = list(), full = FALSE)

Arguments

session

Shiny session variable (in app) or a list (outside of app)

full

Boolean indicating if the full test session should be created (TRUE) or a minimal test session should be created (FALSE, default)

Value

The CTS portion of the all_sess_res returned from FM_app_preload

See Also

FM_app_preload

Examples


session = shiny::MockShinySession$new()
sess_res = CTS_test_mksession(session=session)


ruminate documentation built on Nov. 5, 2025, 5:34 p.m.