| MB_Server | R Documentation |
Server function for the Model Builder Shiny Module
MB_Server(
id,
id_ASM = "ASM",
FM_yaml_file = system.file(package = "formods", "templates", "formods.yaml"),
MOD_yaml_file = system.file(package = "ruminate", "templates", "MB.yaml"),
deployed = FALSE,
react_state = NULL
)
id |
An ID string that corresponds with the ID used to call the modules UI elements |
id_ASM |
ID string for the app state managment module used to save and load app states |
FM_yaml_file |
App configuration file with FM as main section. |
MOD_yaml_file |
Module configuration file with MC as main section. |
deployed |
Boolean variable indicating whether the app is deployed or not. |
react_state |
Variable passed to server to allow reaction outside of module ( |
MB Server object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.