MB_update_checksum: Update MB Module Checksum

View source: R/MB_Server.R

MB_update_checksumR Documentation

Update MB Module Checksum

Description

Takes a MB state and updates the checksum used to trigger downstream updates

Usage

MB_update_checksum(state)

Arguments

state

MB state from MB_fetch_state()

Value

MB state object with the checksum updated

Examples

# Within shiny both session and input variables will exist,
# this creates examples here for testing purposes:
sess_res = MB_test_mksession()
session = sess_res$session
input   = sess_res$input

# We also need a state variable
state = sess_res$state

state = MB_update_checksum(state)

ruminate documentation built on Nov. 5, 2025, 5:34 p.m.