| CTS_sim_isgood | R Documentation |
Takes the supplied element and determines if the underlying simulation is in a good state or not.
CTS_sim_isgood(state, element)
state |
CTS state from |
element |
Element list from |
List with the following elements:
isgood: Boolean object indicating if the file was successfully loaded.
msgs: Text description of failure.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.